' ========================================================================================
' GdipGetHatchForegroundColor
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

' ========================================================================================
' The following example sets up three colors: blue, turquoise, and current
' (initialized to black). A rectangle is painted by using turquoise as the background
' color and blue as the foreground color. Then the GdipGetForegroundColor function is used
' to get the current color of the brush (which at the time is blue). The address of the
' current Color object (initialized to black) is passed as the return point for the call
' to GdipGetForegroundColor. When the rectangle is painted again, notice that the foreground
' color is again blue (not black). This shows that the call to GdipGetForegroundColor was
' successful.
' ========================================================================================
SUB GDIP_GetHatchForegroundColor (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pColorBlue AS DWORD
   LOCAL pColorTurquoise AS DWORD
   LOCAL pColorCurrent AS DWORD
   LOCAL pBrush AS DWORD
   LOCAL pBrush2 AS DWORD

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Set colors.
   pColorBlue = GDIP_ARGB(255, 0, 0, 255)          ' foreground
   pColorTurquoise = GDIP_ARGB(255, 0, 255, 255)   ' background
   pColorCurrent = GDIP_ARGB(255, 0, 0, 0)         ' new background

   ' // Set and then draw the first hatch style.
   hStatus = GdipCreateHatchBrush(%HatchStyleHorizontal, pColorBlue, pColorTurquoise, pBrush)
   hStatus = GdipFillRectangle(pGraphics, pBrush, 20, 20, 100, 50)

   ' // Get the background color of the current brush.
   hStatus = GdipGetHatchForegroundColor(pBrush, pColorCurrent)

   ' // Draw the rectangle again using the current color.
   hStatus = GdipCreateHatchBrush(%HatchStyleDiagonalCross, pColorCurrent, pColorTurquoise, pBrush2)
   hStatus = GdipFillRectangle(pGraphics, pBrush2, 130, 20, 100, 50)

   ' // Cleanup
   IF pBrush THEN GdipDeleteBrush(pBrush)
   IF pBrush2 THEN GdipDeleteBrush(pBrush2)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   DIALOG NEW 0, "GdipGetHatchForegroundColor", , , 280, 170, %WS_OVERLAPPED OR %WS_THICKFRAME OR %WS_SYSMENU OR _
   %WS_MINIMIZEBOX OR %WS_MAXIMIZEBOX OR %WS_VISIBLE OR %DS_CENTER TO hDlg
   DIALOG SET COLOR hDlg, %BLACK, %WHITE
   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   LOCAL hDC AS DWORD
   LOCAL ps AS PAINTSTRUCT

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

      CASE %WM_PAINT
         hDC = BeginPaint(CBHNDL, ps)
         GDIP_GetHatchForegroundColor hDC
         EndPaint(CBHNDL, ps)

   END SELECT

END FUNCTION
' ========================================================================================
